@@ -3,6 +3,7 @@ import requests
 
 REQUEST_TIMEOUT = 20
 
+
 class _StatsigNetwork:
 
     __RETRY_CODES = [408, 500, 502, 503, 504, 522, 524, 599]
@@ -15,7 +16,7 @@ class _StatsigNetwork:
         self.__api = api
         self.__timeout = options.timeout or REQUEST_TIMEOUT
         self.__local_mode = options.local_mode
-    
+
     def post_request(self, endpoint, payload):
         if self.__local_mode:
             return None
@@ -26,7 +27,8 @@ class _StatsigNetwork:
             'STATSIG-CLIENT-TIME': str(round(time.time() * 1000)),
         }
         try:
-            response = requests.post(self.__api + endpoint, json=payload, headers=headers, timeout=self.__timeout)
+            response = requests.post(
+                self.__api + endpoint, json=payload, headers=headers, timeout=self.__timeout)
             if response.status_code == 200:
                 data = response.json()
                 if data:
@@ -35,7 +37,7 @@ class _StatsigNetwork:
                     return None
         except Exception as e:
             return None
-            
+
     def retryable_request(self, endpoint, payload):
         if self.__local_mode:
             return None
@@ -46,7 +48,8 @@ class _StatsigNetwork:
             'STATSIG-CLIENT-TIME': str(round(time.time() * 1000)),
         }
         try:
-            response = requests.post(self.__api + endpoint, json=payload, headers=headers, timeout=self.__timeout)
+            response = requests.post(
+                self.__api + endpoint, json=payload, headers=headers, timeout=self.__timeout)
             if response.status_code in self.__RETRY_CODES:
                 return payload
             else:
